diff --git a/sdk/storage/mgmt-v2017_10_01/pom.xml b/sdk/storage/mgmt-v2017_10_01/pom.xml
index 267ef3b0c7f6f..c74b34e119bdc 100644
--- a/sdk/storage/mgmt-v2017_10_01/pom.xml
+++ b/sdk/storage/mgmt-v2017_10_01/pom.xml
@@ -11,15 +11,15 @@
com.microsoft.azure
azure-arm-parent
- 1.3.0
- ../../parents/azure-arm-parent
+ 1.1.0
+ ../../../pom.management.xml
azure-mgmt-storage
- 1.0.0-beta-1
+ 1.0.0-beta
jar
Microsoft Azure SDK for Storage Management
This package contains Microsoft Storage Management SDK.
- https://github.com/Azure/azure-libraries-for-java
+ https://github.com/Azure/azure-sdk-for-java
The MIT License (MIT)
@@ -28,8 +28,8 @@
- scm:git:https://github.com/Azure/azure-libraries-for-java
- scm:git:git@github.com:Azure/azure-libraries-for-java.git
+ scm:git:https://github.com/Azure/azure-sdk-for-java
+ scm:git:git@github.com:Azure/azure-sdk-for-java.git
HEAD
@@ -71,6 +71,8 @@
azure-arm-client-runtime
test-jar
test
+
+ 1.6.5
diff --git a/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/Dimension.java b/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/Dimension.java
index 9cb5f123501e9..c0838ab51b96e 100644
--- a/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/Dimension.java
+++ b/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/Dimension.java
@@ -11,7 +11,7 @@
import com.fasterxml.jackson.annotation.JsonProperty;
/**
- * Dimension of blobs, possiblly be blob type or access tier.
+ * Dimension of blobs, possibly be blob type or access tier.
*/
public class Dimension {
/**
diff --git a/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/ServiceSasParameters.java b/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/ServiceSasParameters.java
index 033862f56610c..fee6c492b651e 100644
--- a/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/ServiceSasParameters.java
+++ b/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/ServiceSasParameters.java
@@ -12,7 +12,7 @@
import com.fasterxml.jackson.annotation.JsonProperty;
/**
- * The parameters to list service SAS credentials of a speicific resource.
+ * The parameters to list service SAS credentials of a specific resource.
*/
public class ServiceSasParameters {
/**
diff --git a/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/StorageAccount.java b/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/StorageAccount.java
index 0a7a5fe13744d..6f8f1fe746c5f 100644
--- a/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/StorageAccount.java
+++ b/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/StorageAccount.java
@@ -139,7 +139,9 @@ interface WithGroup extends GroupableResourceCore.DefinitionStages.WithGroup, Resource.UpdateWithTags listKeysDelegate(Resp
*
* @param resourceGroupName The name of the resource group within the user's subscription. The name is case insensitive.
* @param accountName The name of the storage account within the specified resource group. Storage account names must be between 3 and 24 characters in length and use numbers and lower-case letters only.
- * @param keyName The name of storage keys that want to be regenerated, possible vaules are key1, key2.
+ * @param keyName The name of storage keys that want to be regenerated, possible values are key1, key2.
* @throws IllegalArgumentException thrown if parameters fail the validation
* @throws CloudException thrown if the request is rejected by server
* @throws RuntimeException all other wrapped checked exceptions if the request fails to be sent
@@ -913,7 +913,7 @@ public StorageAccountListKeysResultInner regenerateKey(String resourceGroupName,
*
* @param resourceGroupName The name of the resource group within the user's subscription. The name is case insensitive.
* @param accountName The name of the storage account within the specified resource group. Storage account names must be between 3 and 24 characters in length and use numbers and lower-case letters only.
- * @param keyName The name of storage keys that want to be regenerated, possible vaules are key1, key2.
+ * @param keyName The name of storage keys that want to be regenerated, possible values are key1, key2.
* @param serviceCallback the async ServiceCallback to handle successful and failed responses.
* @throws IllegalArgumentException thrown if parameters fail the validation
* @return the {@link ServiceFuture} object
@@ -927,7 +927,7 @@ public ServiceFuture regenerateKeyAsync(Strin
*
* @param resourceGroupName The name of the resource group within the user's subscription. The name is case insensitive.
* @param accountName The name of the storage account within the specified resource group. Storage account names must be between 3 and 24 characters in length and use numbers and lower-case letters only.
- * @param keyName The name of storage keys that want to be regenerated, possible vaules are key1, key2.
+ * @param keyName The name of storage keys that want to be regenerated, possible values are key1, key2.
* @throws IllegalArgumentException thrown if parameters fail the validation
* @return the observable to the StorageAccountListKeysResultInner object
*/
@@ -945,7 +945,7 @@ public StorageAccountListKeysResultInner call(ServiceResponse
diff --git a/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/CustomDomain.java b/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/CustomDomain.java
index cbc14318cf296..34895ed0bda08 100644
--- a/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/CustomDomain.java
+++ b/sdk/storage/mgmt-v2017_10_01/src/main/java/com/microsoft/azure/management/storage/v2017_10_01/CustomDomain.java
@@ -26,8 +26,8 @@ public class CustomDomain {
* Indicates whether indirect CName validation is enabled. Default value is
* false. This should only be set on updates.
*/
- @JsonProperty(value = "useSubDomain")
- private Boolean useSubDomain;
+ @JsonProperty(value = "useSubDomainName")
+ private Boolean useSubDomainName;
/**
* Get gets or sets the custom domain name assigned to the storage account. Name is the CNAME source.
@@ -52,20 +52,20 @@ public CustomDomain withName(String name) {
/**
* Get indicates whether indirect CName validation is enabled. Default value is false. This should only be set on updates.
*
* @return the useSubDomain value
*/
- public Boolean useSubDomain() {
- return this.useSubDomain;
+ public Boolean useSubDomainName() {
+ return this.useSubDomainName;
}
/**
* Set indicates whether indirect CName validation is enabled. Default value is false. This should only be set on updates.
*
* @param useSubDomain the useSubDomain value to set
* @return the CustomDomain object itself.
*/
- public CustomDomain withUseSubDomain(Boolean useSubDomain) {
- this.useSubDomain = useSubDomain;
+ public CustomDomain withUseSubDomainName(Boolean useSubDomainName) {
+ this.useSubDomainName = useSubDomainName;
return this;
}
@@ -52,20 +52,20 @@ public CustomDomain withName(String name) {
* Get indicates whether indirect CName validation is enabled. Default value is false. This should only be set on updates.
*
- * @return the useSubDomain value
+ * @return the useSubDomainName value
*/
@@ -52,20 +52,20 @@ public CustomDomain withName(String name) {
* Set indicates whether indirect CName validation is enabled. Default value is false. This should only be set on updates.
*
- * @param useSubDomain the useSubDomain value to set
+ * @param useSubDomainName the useSubDomainName value to set
* @return the CustomDomain object itself.
*/